@@ -117,12 +117,12 @@ WebEnginePage::WebEnginePage(WebEnginePart *part, QWidget *parent)
     };
     connect(this, &QWebEnginePage::loadFinished, this, unsetInspectedPageIfNeeded);
 
-    WebEnginePartControls::self()->navigationRecorder()->registerPage(this);
+    controls()->navigationRecorder()->registerPage(this);
     m_part->downloadManager()->addPage(this);
 
     setBackgroundColor(WebEngineSettings::self()->customBackgroundColor());
-    connect(WebEnginePartControls::self(), &WebEnginePartControls::updateBackgroundColor, this, [this](const QColor &color){setBackgroundColor(color);});
-    connect(WebEnginePartControls::self(), &WebEnginePartControls::updateStyleSheet, this, &WebEnginePage::updateUserStyleSheet);
+    connect(controls(), &WebEnginePartControls::updateBackgroundColor, this, [this](const QColor &color){setBackgroundColor(color);});
+    connect(controls(), &WebEnginePartControls::updateStyleSheet, this, &WebEnginePage::updateUserStyleSheet);
 }
 
 WebEnginePage::~WebEnginePage()
@@ -130,6 +130,11 @@ WebEnginePage::~WebEnginePage()
 //qCDebug(WEBENGINEPART_LOG) << this;
 }
 
+inline WebEnginePartControls* WebEnginePage::controls() const
+{
+    return WebEnginePartControls::self();
+}
+
 const WebSslInfo& WebEnginePage::sslInfo() const
 {
     return m_sslInfo;
@@ -237,7 +242,7 @@ void WebEnginePage::requestDownload(QWebEngineDownloadRequest *item, bool newWin
     emit m_part->browserExtension()->browserOpenUrlRequestSync(url, args, bArgs, true);
 
     if (item->state() == QWebEngineDownloadRequest::DownloadRequested) {
-        qCDebug(WEBENGINEPART_LOG()) << "Automatically accepting download for" << item->url() << "This shouldn't happen";
+        qCDebug(WEBENGINEPART_LOG) << "Automatically accepting download for" << item->url() << "This shouldn't happen";
         item->accept();
     }
 
@@ -281,13 +286,14 @@ bool WebEnginePage::shouldOpenUrl(const QUrl& url) const
     if (!url.isLocalFile()) {
         return true;
     }
-    BrowserInterface *bi = m_part->browserExtension()->browserInterface();
-    bool useThisPart = false;
-    //We don't check whether bi is valid, as invokeMethod will fail if it's nullptr
-    //If invokeMethod fails, useThisPart will keep its default value (false) which is what we need to return, so there's no
-    //need to check the return value of invokeMethod
-    QMetaObject::invokeMethod(bi, "isCorrectPartForLocalFile", Q_RETURN_ARG(bool, useThisPart), Q_ARG(KParts::ReadOnlyPart*, part()), Q_ARG(QString, url.path()));
-    return useThisPart;
+
+    KonqInterfaces::Browser *iface = KonqInterfaces::Browser::browser(qApp);
+    if (!iface) {
+        qCDebug(WEBENGINEPART_LOG) << "Konqueror application should provide BrowserInterface but it doesn't";
+        return true;
+    }
+    QString partToUse = iface->partForLocalFile(url.path(), part()->arguments().mimeType());
+    return partToUse == part()->metaData().pluginId();
 }
 
 bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type, bool isMainFrame)
@@ -296,6 +302,7 @@ bool WebEnginePage::acceptNavigationRequest(const QUrl& url, NavigationType type
     if (isMainFrame) {
         KonqInterfaces::Browser *browser = KonqInterfaces::Browser::browser(qApp);
         if (browser && !browser->canNavigateTo(part(), url)) {
+            askBrowserToOpenUrl(url);
             return false;
         }
     }
@@ -777,11 +784,13 @@ void WebEnginePage::setStatusBarText(const QString& text)
 
 void WebEnginePage::changeLifecycleState(QWebEnginePage::LifecycleState recommendedState)
 {
-    if (recommendedState != QWebEnginePage::LifecycleState::Active && !isVisible()) {
-        setLifecycleState(QWebEnginePage::LifecycleState::Frozen);
-    } else {
-        setLifecycleState(QWebEnginePage::LifecycleState::Active);
+    using State = QWebEnginePage::LifecycleState;
+
+    State newState = State::Active;
+    if (recommendedState != State::Active && !isVisible() && controls()->isPageLifecycleManagementEnabled()) {
+        newState = State::Frozen;
     }
+    setLifecycleState(newState);
 }
 
 void WebEnginePage::updateUserStyleSheet(const QString& script)
@@ -889,6 +898,7 @@ bool NewWindowPage::acceptNavigationRequest(const QUrl &url, NavigationType type
     WindowArgs wargs (m_windowArgs);
 
     KParts::ReadOnlyPart* newWindowPart = nullptr;
+    m_createNewWindow = false;
     emit part()->browserExtension()->browserCreateNewWindow(url, uargs, bargs, wargs, &newWindowPart);
     qCDebug(WEBENGINEPART_LOG) << "Created new window" << newWindowPart;
 
